==> kubernetes-model-1.0.46-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeDaemonEndpointsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class NodeDaemonEndpointsBuilder extends NodeDaemonEndpointsFluentImpl<NodeDaemonEndpointsBuilder> implements VisitableBuilder<NodeDaemonEndpoints,NodeDaemonEndpointsBuilder>{

     NodeDaemonEndpointsFluent<?> fluent;
public NodeDaemonEndpointsBuilder(){
    this(new NodeDaemonEndpoints());
}
public NodeDaemonEndpointsBuilder( NodeDaemonEndpointsFluent<?> fluent ){
    this(fluent, new NodeDaemonEndpoints());
}
public NodeDaemonEndpointsBuilder( NodeDaemonEndpointsFluent<?> fluent , NodeDaemonEndpoints instance ){
    this.fluent = fluent; fluent.withKubeletEndpoint(instance.getKubeletEndpoint()); 
}
public NodeDaemonEndpointsBuilder( NodeDaemonEndpoints instance ){
    this.fluent = this; this.withKubeletEndpoint(instance.getKubeletEndpoint()); 
}

public EditableNodeDaemonEndpoints build(){
    EditableNodeDaemonEndpoints buildable = new EditableNodeDaemonEndpoints(fluent.getKubeletEndpoint());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NodeDaemonEndpointsBuilder that = (NodeDaemonEndpointsBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.51-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeDaemonEndpointsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class NodeDaemonEndpointsBuilder extends NodeDaemonEndpointsFluentImpl<NodeDaemonEndpointsBuilder> implements VisitableBuilder<NodeDaemonEndpoints,NodeDaemonEndpointsBuilder>{

     NodeDaemonEndpointsFluent<?> fluent;
public NodeDaemonEndpointsBuilder(){
    this(new NodeDaemonEndpoints());
}
public NodeDaemonEndpointsBuilder( NodeDaemonEndpointsFluent<?> fluent ){
    this(fluent, new NodeDaemonEndpoints());
}
public NodeDaemonEndpointsBuilder( NodeDaemonEndpointsFluent<?> fluent , NodeDaemonEndpoints instance ){
    this.fluent = fluent; fluent.withKubeletEndpoint(instance.getKubeletEndpoint()); 
}
public NodeDaemonEndpointsBuilder( NodeDaemonEndpoints instance ){
    this.fluent = this; this.withKubeletEndpoint(instance.getKubeletEndpoint()); 
}

public NodeDaemonEndpoints build(){
    NodeDaemonEndpoints buildable = new NodeDaemonEndpoints(fluent.getKubeletEndpoint());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NodeDaemonEndpointsBuilder that = (NodeDaemonEndpointsBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
